@@ -2,3 +2,5 @@ from torchimize.functions.gna_fun import lsq_gna
 from torchimize.functions.lma_fun import lsq_lma
 from torchimize.functions.gna_fun_parallel import lsq_gna_parallel, lsq_gna_parallel_plain
 from torchimize.functions.lma_fun_parallel import lsq_lma_parallel
+from torchimize.functions.newton_parallel import newton_step_parallel
+from torchimize.functions.fun_dims import test_fun_dims_parallel
\ No newline at end of file
